@@ -34,7 +34,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  The XShearImage() and YShearImage() methods are based on the paper "A Fast
-%  Algorithm for General Raster Rotatation" by Alan W. Paeth, Graphics
+%  Algorithm for General Raster Rotation" by Alan W. Paeth, Graphics
 %  Interface '86 (Vancouver).  ShearRotateImage() is adapted from a similar
 %  method based on the Paeth paper written by Michael Halle of the Spatial
 %  Imaging Group, MIT Media Lab.
