@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2016 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2017 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -41,9 +41,9 @@
   Include declarations.
 */
 #include "MagickCore/studio.h"
-#include "MagickCore/property.h"
 #include "MagickCore/accelerate-private.h"
 #include "MagickCore/animate.h"
+#include "MagickCore/artifact.h"
 #include "MagickCore/blob.h"
 #include "MagickCore/blob-private.h"
 #include "MagickCore/cache.h"
@@ -78,6 +78,7 @@
 #include "MagickCore/paint.h"
 #include "MagickCore/pixel-accessor.h"
 #include "MagickCore/profile.h"
+#include "MagickCore/property.h"
 #include "MagickCore/quantize.h"
 #include "MagickCore/quantum-private.h"
 #include "MagickCore/random_.h"
@@ -645,7 +646,7 @@ MagickExport Image *EvaluateImages(const Image *images,
             register ssize_t
               i;
 
-            if (GetPixelReadMask(next,p) == 0)
+            if (GetPixelWriteMask(next,p) == 0)
               {
                 p+=GetPixelChannels(next);
                 continue;
@@ -710,7 +711,7 @@ MagickExport Image *EvaluateImages(const Image *images,
           register ssize_t
             i;
 
-          if (GetPixelReadMask(image,q) == 0)
+          if (GetPixelWriteMask(image,q) == 0)
             {
               q+=GetPixelChannels(image);
               continue;
@@ -826,7 +827,7 @@ MagickExport MagickBooleanType EvaluateImage(Image *image,
         if (traits == UndefinedPixelTrait)
           continue;
         if (((traits & CopyPixelTrait) != 0) ||
-            (GetPixelReadMask(image,q) == 0))
+            (GetPixelWriteMask(image,q) == 0))
           continue;
         result=ApplyEvaluateOperator(random_info[id],q[i],op,value);
         if (op == MeanEvaluateOperator)
@@ -1046,7 +1047,7 @@ MagickExport MagickBooleanType FunctionImage(Image *image,
       register ssize_t
         i;
 
-      if (GetPixelReadMask(image,q) == 0)
+      if (GetPixelWriteMask(image,q) == 0)
         {
           q+=GetPixelChannels(image);
           continue;
@@ -1294,7 +1295,7 @@ MagickExport MagickBooleanType GetImageKurtosis(const Image *image,
       register ssize_t
         i;
 
-      if (GetPixelReadMask(image,p) == 0)
+      if (GetPixelWriteMask(image,p) == 0)
         {
           p+=GetPixelChannels(image);
           continue;
@@ -1542,7 +1543,7 @@ MagickExport ChannelMoments *GetImageMoments(const Image *image,
       register ssize_t
         i;
 
-      if (GetPixelReadMask(image,p) == 0)
+      if (GetPixelWriteMask(image,p) == 0)
         {
           p+=GetPixelChannels(image);
           continue;
@@ -1600,7 +1601,7 @@ MagickExport ChannelMoments *GetImageMoments(const Image *image,
       register ssize_t
         i;
 
-      if (GetPixelReadMask(image,p) == 0)
+      if (GetPixelWriteMask(image,p) == 0)
         {
           p+=GetPixelChannels(image);
           continue;
@@ -1772,86 +1773,88 @@ static inline double MagickLog10(const double x)
 {
 #define Log10Epsilon  (1.0e-11)
 
- if (fabs(x) < Log10Epsilon)
-   return(log10(Log10Epsilon));
- return(log10(fabs(x)));
+  if (fabs(x) < Log10Epsilon)
+    return(log10(Log10Epsilon));
+  return(log10(fabs(x)));
 }
 
-MagickExport ChannelPerceptualHash *GetImagePerceptualHash(
-  const Image *image,ExceptionInfo *exception)
+MagickExport ChannelPerceptualHash *GetImagePerceptualHash(const Image *image,
+  ExceptionInfo *exception)
 {
-  ChannelMoments
-    *moments;
-
   ChannelPerceptualHash
     *perceptual_hash;
 
-  Image
-    *hash_image;
+  char
+    *colorspaces,
+    *q;
+
+  const char
+    *artifact;
 
   MagickBooleanType
     status;
 
+  register char
+    *p;
+
   register ssize_t
     i;
 
-  ssize_t
-    channel;
-
-  /*
-    Blur then transform to sRGB colorspace.
-  */
-  hash_image=BlurImage(image,0.0,1.0,exception);
-  if (hash_image == (Image *) NULL)
-    return((ChannelPerceptualHash *) NULL);
-  hash_image->depth=8;
-  status=TransformImageColorspace(hash_image,sRGBColorspace,exception);
-  if (status == MagickFalse)
-    return((ChannelPerceptualHash *) NULL);
-  moments=GetImageMoments(hash_image,exception);
-  hash_image=DestroyImage(hash_image);
-  if (moments == (ChannelMoments *) NULL)
-    return((ChannelPerceptualHash *) NULL);
   perceptual_hash=(ChannelPerceptualHash *) AcquireQuantumMemory(
     MaxPixelChannels+1UL,sizeof(*perceptual_hash));
   if (perceptual_hash == (ChannelPerceptualHash *) NULL)
     return((ChannelPerceptualHash *) NULL);
-  for (channel=0; channel <= MaxPixelChannels; channel++)
-    for (i=0; i < MaximumNumberOfImageMoments; i++)
-      perceptual_hash[channel].srgb_hu_phash[i]=
-        (-MagickLog10(moments[channel].invariant[i]));
-  moments=(ChannelMoments *) RelinquishMagickMemory(moments);
-  /*
-    Blur then transform to HCLp colorspace.
-  */
-  hash_image=BlurImage(image,0.0,1.0,exception);
-  if (hash_image == (Image *) NULL)
-    {
-      perceptual_hash=(ChannelPerceptualHash *) RelinquishMagickMemory(
-        perceptual_hash);
-      return((ChannelPerceptualHash *) NULL);
-    }
-  hash_image->depth=8;
-  status=TransformImageColorspace(hash_image,HCLpColorspace,exception);
-  if (status == MagickFalse)
-    {
-      perceptual_hash=(ChannelPerceptualHash *) RelinquishMagickMemory(
-        perceptual_hash);
-      return((ChannelPerceptualHash *) NULL);
-    }
-  moments=GetImageMoments(hash_image,exception);
-  hash_image=DestroyImage(hash_image);
-  if (moments == (ChannelMoments *) NULL)
-    {
-      perceptual_hash=(ChannelPerceptualHash *) RelinquishMagickMemory(
-        perceptual_hash);
-      return((ChannelPerceptualHash *) NULL);
-    }
-  for (channel=0; channel <= MaxPixelChannels; channel++)
-    for (i=0; i < MaximumNumberOfImageMoments; i++)
-      perceptual_hash[channel].hclp_hu_phash[i]=
-        (-MagickLog10(moments[channel].invariant[i]));
-  moments=(ChannelMoments *) RelinquishMagickMemory(moments);
+  artifact=GetImageArtifact(image,"phash:colorspaces");
+  if (artifact != NULL)
+    colorspaces=AcquireString(artifact);
+  else
+    colorspaces=AcquireString("sRGB,HCLp");
+  perceptual_hash[0].number_colorspaces=0;
+  perceptual_hash[0].number_channels=0;
+  q=colorspaces;
+  for (i=0; (p=StringToken(",",&q)) != (char *) NULL; i++)
+  {
+    ChannelMoments
+      *moments;
+
+    Image
+      *hash_image;
+
+
+    size_t
+      j;
+
+    ssize_t
+      channel,
+      colorspace;
+
+    if (i >= MaximumNumberOfPerceptualColorspaces)
+      break;
+    colorspace=ParseCommandOption(MagickColorspaceOptions,MagickFalse,p);
+    if (colorspace < 0)
+      break;
+    perceptual_hash[0].colorspace[i]=(ColorspaceType) colorspace;
+    hash_image=BlurImage(image,0.0,1.0,exception);
+    if (hash_image == (Image *) NULL)
+      break;
+    hash_image->depth=8;
+    status=TransformImageColorspace(hash_image,(ColorspaceType) colorspace,
+      exception);
+    if (status == MagickFalse)
+      break;
+    moments=GetImageMoments(hash_image,exception);
+    perceptual_hash[0].number_colorspaces++;
+    perceptual_hash[0].number_channels+=GetImageChannels(hash_image);
+    hash_image=DestroyImage(hash_image);
+    if (moments == (ChannelMoments *) NULL)
+      break;
+    for (channel=0; channel <= MaxPixelChannels; channel++)
+      for (j=0; j < MaximumNumberOfImageMoments; j++)
+        perceptual_hash[channel].phash[i][j]=
+          (-MagickLog10(moments[channel].invariant[j]));
+    moments=(ChannelMoments *) RelinquishMagickMemory(moments);
+  }
+  colorspaces=DestroyString(colorspaces);
   return(perceptual_hash);
 }
 
@@ -1939,7 +1942,7 @@ MagickExport MagickBooleanType GetImageRange(const Image *image,double *minima,
       register ssize_t
         i;
 
-      if (GetPixelReadMask(image,p) == 0)
+      if (GetPixelWriteMask(image,p) == 0)
         {
           p+=GetPixelChannels(image);
           continue;
@@ -2093,7 +2096,7 @@ MagickExport ChannelStatistics *GetImageStatistics(const Image *image,
       register ssize_t
         i;
 
-      if (GetPixelReadMask(image,p) == 0)
+      if (GetPixelWriteMask(image,p) == 0)
         {
           p+=GetPixelChannels(image);
           continue;
@@ -2162,8 +2165,9 @@ MagickExport ChannelStatistics *GetImageStatistics(const Image *image,
         count;
 
       count=histogram[GetPixelChannels(image)*j+i]*area;
-      channel_statistics[i].entropy+=-count*MagickLog10(count)/
-        MagickLog10(number_bins);
+      if (number_bins > MagickEpsilon)
+        channel_statistics[i].entropy+=-count*MagickLog10(count)/
+          MagickLog10(number_bins);
     }
   }
   for (i=0; i < (ssize_t) MaxPixelChannels; i++)
@@ -2389,7 +2393,7 @@ MagickExport Image *PolynomialImage(const Image *images,
         register ssize_t
           i;
 
-        if (GetPixelReadMask(next,p) == 0)
+        if (GetPixelWriteMask(next,p) == 0)
           {
             p+=GetPixelChannels(next);
             continue;
@@ -2423,7 +2427,7 @@ MagickExport Image *PolynomialImage(const Image *images,
       register ssize_t
         i;
 
-      if (GetPixelReadMask(image,q) == 0)
+      if (GetPixelWriteMask(image,q) == 0)
         {
           q+=GetPixelChannels(image);
           continue;
@@ -3066,7 +3070,7 @@ MagickExport Image *StatisticImage(const Image *image,const StatisticType type,
             (statistic_traits == UndefinedPixelTrait))
           continue;
         if (((statistic_traits & CopyPixelTrait) != 0) ||
-            (GetPixelReadMask(image,p) == 0))
+            (GetPixelWriteMask(image,p) == 0))
           {
             SetPixelChannel(statistic_image,channel,p[center+i],q);
             continue;
